@@ -17,11 +17,9 @@ GNU General Public License for more details.
 You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 ***/
-#ifndef FILELOADER_H
-#define FILELOADER_H
+#pragma once
 
 #include <QDir>
-#include <QDirIterator>
 #include <QObject>
 #include <QThread>
 #include <QUrl>
@@ -67,7 +65,7 @@ private slots:
      * @param limit
      */
     void getFiles(QList<QUrl> paths, bool recursive, const QStringList &nameFilters, const QDir::Filters &filters, uint limit);
-
+   
 signals:
     /**
      * @brief finished
@@ -103,4 +101,3 @@ private:
 };
 }
 
-#endif // FILELOADER_H
